==> react-ui-library-7.0.0.tgz: package/src/stories/input-story.js <==
import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Input,
  Pane,
  Display4,
  theme
} from '../components'
import Content from './Content'
const { minorScale, majorScale } = theme

export default function inputStory (module) {
  storiesOf('Input', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Input

The Input component is an \`input\` element. Implement the \`<Box />\` component.

\`\`\`
<Input marginBottom={majorScale(2)} />
<Input warning />
\`\`\`

`}
          </Content>
          <Display4 display='inline-block' marginRight={majorScale(1)} marginY={majorScale(2)}>Default</Display4>
          <Input marginBottom={majorScale(2)} />
          <Input warning />

          <Display4 display='inline-block' marginRight={majorScale(1)} marginY={majorScale(2)}>Small</Display4>
          <Input size='default' marginBottom={majorScale(2)} />
          <Input size='default' warning />
          <Content markdown>
            {`
prop | version | type | default | description
-----|---------|------| --------|-------------
\`size\`| v3.0.0 | \`default\`, \`small\` | \`default\` | as defined by \`theme.controlSizes\`
\`warning\` | v2 | boolean | undefined | toggles \`<ExclamationCircle />\` on the side
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <Input />
    ))
    .add('with margins', () => (
      <Pane white>
        <Input margin={minorScale(3)} />
      </Pane>
    ))
    .add('with width', () => (
      <Pane white>
        <Input width='240px' margin={minorScale(3)} />
      </Pane>
    ))
}

==> react-ui-library-7.4.0.tgz: package/src/stories/input-story.js <==
import React from 'react'
import { storiesOf } from '@kadira/storybook'
import {
  App,
  Input,
  Pane,
  Display4,
  theme
} from '../components'
import Content from './Content'
const { minorScale, majorScale } = theme

export default function inputStory (module) {
  storiesOf('Input', module)
    .add('usage', () => (
      <App white>
        <Pane white padding={majorScale(10)}>
          <Content markdown>
            {`
# Input

The Input component is an \`input\` element. Implement the \`<Box />\` component.

\`\`\`
<Input marginBottom={majorScale(2)} />
<Input warning />
\`\`\`

`}
          </Content>
          <Display4 display='inline-block' marginRight={majorScale(1)} marginY={majorScale(2)}>Default</Display4>
          <Input marginBottom={majorScale(2)} />
          <Input warning />

          <Display4 display='inline-block' marginRight={majorScale(1)} marginY={majorScale(2)}>Small</Display4>
          <Input size='small' marginBottom={majorScale(2)} />
          <Input size='small' warning />
          <Content markdown>
            {`
prop | version | type | default | description
-----|---------|------| --------|-------------
\`size\`| v3.0.0 | \`default\`, \`small\` | \`default\` | as defined by \`theme.controlSizes\`
\`warning\` | v2 | boolean | undefined | toggles \`<ExclamationCircle />\` on the side
`}
          </Content>
        </Pane>
      </App>
    ))
    .add('standalone', () => (
      <Input />
    ))
    .add('with margins', () => (
      <Pane white>
        <Input margin={minorScale(3)} />
      </Pane>
    ))
    .add('with width', () => (
      <Pane white>
        <Input width='240px' margin={minorScale(3)} />
      </Pane>
    ))
}
